@@ -4,10 +4,14 @@ package Thread::Queue::Monitored;
 # Make sure we have version info for this module
 # Make sure we do everything by the book from now on
 
-our @ISA : unique = qw(Thread::Queue);
-our $VERSION : unique = '0.06';
+@ISA = qw(Thread::Queue);
+$VERSION = '0.07';
 use strict;
 
+# Satisfy -require-
+
+1;
+
 # Make sure we have queues
 
 use Thread::Queue (); # no need to pollute namespace
@@ -410,8 +414,8 @@ queue.  The queue will grow as needed to accommodate the list.  If the
 =head1 CAVEATS
 
 You cannot remove any values from the queue, as that is done by the monitoring
-thread.  Therefore, the methods "dequeue" and "dequeue_nb" are disabled on
-this object.
+thread.  Therefore, the methods "dequeue", "dequeue_dontwait" and
+"dequeue_keep" are disabled on this object.
 
 =head1 AUTHOR
 
@@ -421,7 +425,7 @@ Please report bugs to <perlbugs@dijkmat.nl>.
 
 =head1 COPYRIGHT
 
-Copyright (c) 2002 Elizabeth Mattijsen <liz@dijkmat.nl>. All rights
+Copyright (c) 2002-2003 Elizabeth Mattijsen <liz@dijkmat.nl>. All rights
 reserved.  This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
 
